@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 import sys
 sys.path.append('./')
-from comFunction import half_wave_file,set_mac_volume,recovery_mac_volume,str_2_bool,polqa_client_test,match_sig,play_and_rec
+from common.comFunction import half_wave_file,set_mac_volume,recovery_mac_volume,str_2_bool,polqa_client_test,match_sig,play_and_rec
 import os
 
 class main_process():
